@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: mozilla-embed-single.cpp 7208 2007-07-27 20:27:56Z xan $
+ *  $Id: mozilla-embed-single.cpp 7225 2007-07-30 21:50:44Z xan $
  */
 
 #include "mozilla-config.h"
@@ -137,6 +137,10 @@ static void mozilla_embed_single_init		(MozillaEmbedSingle *ges);
 static void ephy_certificate_manager_iface_init	(EphyCertificateManagerIface *iface);
 #endif
 
+/* Some compilers (like gcc 2.95) don't support preprocessor directives inside macros,
+   so we have to duplicate the whole thing */
+
+#ifdef ENABLE_CERTIFICATE_MANAGER
 G_DEFINE_TYPE_WITH_CODE (MozillaEmbedSingle, mozilla_embed_single, G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (EPHY_TYPE_EMBED_SINGLE,
                                                 ephy_embed_single_iface_init)
@@ -144,12 +148,21 @@ G_DEFINE_TYPE_WITH_CODE (MozillaEmbedSingle, mozilla_embed_single, G_TYPE_OBJECT
                                                 ephy_cookie_manager_iface_init)
                          G_IMPLEMENT_INTERFACE (EPHY_TYPE_PASSWORD_MANAGER,
                                                 ephy_password_manager_iface_init)
-#ifdef ENABLE_CERTIFICATE_MANAGER
                          G_IMPLEMENT_INTERFACE (EPHY_TYPE_CERTIFICATE_MANAGER,
                                                 ephy_certificate_manager_iface_init)
-#endif
                          G_IMPLEMENT_INTERFACE (EPHY_TYPE_PERMISSION_MANAGER,
                                                 ephy_permission_manager_iface_init))
+#else
+G_DEFINE_TYPE_WITH_CODE (MozillaEmbedSingle, mozilla_embed_single, G_TYPE_OBJECT,
+                         G_IMPLEMENT_INTERFACE (EPHY_TYPE_EMBED_SINGLE,
+                                                ephy_embed_single_iface_init)
+                         G_IMPLEMENT_INTERFACE (EPHY_TYPE_COOKIE_MANAGER,
+                                                ephy_cookie_manager_iface_init)
+                         G_IMPLEMENT_INTERFACE (EPHY_TYPE_PASSWORD_MANAGER,
+                                                ephy_password_manager_iface_init)
+                         G_IMPLEMENT_INTERFACE (EPHY_TYPE_PERMISSION_MANAGER,
+                                                ephy_permission_manager_iface_init))
+#endif
 
 static gboolean
 mozilla_set_default_prefs (MozillaEmbedSingle *mes)
@@ -672,6 +685,8 @@ mozilla_embed_single_finalize (GObject *object)
 {
 	MozillaEmbedSingle *mes = MOZILLA_EMBED_SINGLE (object);
 
+	g_free (mes->priv->user_prefs);
+
 	/* Destroy EphyEmbedSingle before because some
 	 * services depend on xpcom */
 	G_OBJECT_CLASS (mozilla_embed_single_parent_class)->finalize (object);
@@ -683,8 +698,6 @@ mozilla_embed_single_finalize (GObject *object)
 #ifdef HAVE_GECKO_1_9
 	NS_LogTerm ();
 #endif
-
-	g_free (mes->priv->user_prefs);
 }
 
 static void
